Package com.babelqueue
Record Class Meta
java.lang.Object
java.lang.Record
com.babelqueue.Meta
- Record Components:
id- a unique identifier for this specific messagequeue- the logical queue the message was produced forlang- the source SDK language (e.g."java")schemaVersion- the wire envelope schema versioncreatedAt- creation time in Unix milliseconds, UTC
public record Meta(String id, String queue, String lang, int schemaVersion, long createdAt)
extends Record
The immutable per-message metadata block of a
Envelope.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionlongReturns the value of thecreatedAtrecord component.final booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.id()Returns the value of theidrecord component.lang()Returns the value of thelangrecord component.queue()Returns the value of thequeuerecord component.intReturns the value of theschemaVersionrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
Meta
Creates an instance of aMetarecord class.- Parameters:
id- the value for theidrecord componentqueue- the value for thequeuerecord componentlang- the value for thelangrecord componentschemaVersion- the value for theschemaVersionrecord componentcreatedAt- the value for thecreatedAtrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
id
Returns the value of theidrecord component.- Returns:
- the value of the
idrecord component
-
queue
Returns the value of thequeuerecord component.- Returns:
- the value of the
queuerecord component
-
lang
Returns the value of thelangrecord component.- Returns:
- the value of the
langrecord component
-
schemaVersion
public int schemaVersion()Returns the value of theschemaVersionrecord component.- Returns:
- the value of the
schemaVersionrecord component
-
createdAt
public long createdAt()Returns the value of thecreatedAtrecord component.- Returns:
- the value of the
createdAtrecord component
-