Record Class Redrive.Item

java.lang.Object
java.lang.Record
com.babelqueue.Redrive.Item
Enclosing class:
Redrive

public static record Redrive.Item(String messageId, String traceId, String urn, String reason, String from, String to, boolean redriven, boolean bypassed) extends Record
  • Constructor Summary

    Constructors
    Constructor
    Description
    Item(String messageId, String traceId, String urn, String reason, String from, String to, boolean redriven, boolean bypassed)
    Creates an instance of a Item record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    boolean
    Returns the value of the bypassed record component.
    final boolean
    Indicates whether some other object is "equal to" this one.
    Returns the value of the from record component.
    final int
    Returns a hash code value for this object.
    Returns the value of the messageId record component.
    Returns the value of the reason record component.
    boolean
    Returns the value of the redriven record component.
    to()
    Returns the value of the to record component.
    final String
    Returns a string representation of this record class.
    Returns the value of the traceId record component.
    urn()
    Returns the value of the urn record component.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • Item

      public Item(String messageId, String traceId, String urn, String reason, String from, String to, boolean redriven, boolean bypassed)
      Creates an instance of a Item record class.
      Parameters:
      messageId - the value for the messageId record component
      traceId - the value for the traceId record component
      urn - the value for the urn record component
      reason - the value for the reason record component
      from - the value for the from record component
      to - the value for the to record component
      redriven - the value for the redriven record component
      bypassed - the value for the bypassed record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared with Objects::equals(Object,Object); primitive components are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • messageId

      public String messageId()
      Returns the value of the messageId record component.
      Returns:
      the value of the messageId record component
    • traceId

      public String traceId()
      Returns the value of the traceId record component.
      Returns:
      the value of the traceId record component
    • urn

      public String urn()
      Returns the value of the urn record component.
      Returns:
      the value of the urn record component
    • reason

      public String reason()
      Returns the value of the reason record component.
      Returns:
      the value of the reason record component
    • from

      public String from()
      Returns the value of the from record component.
      Returns:
      the value of the from record component
    • to

      public String to()
      Returns the value of the to record component.
      Returns:
      the value of the to record component
    • redriven

      public boolean redriven()
      Returns the value of the redriven record component.
      Returns:
      the value of the redriven record component
    • bypassed

      public boolean bypassed()
      Returns the value of the bypassed record component.
      Returns:
      the value of the bypassed record component