Record Class Redrive.Reserved

java.lang.Object
java.lang.Record
com.babelqueue.Redrive.Reserved
Enclosing class:
Redrive

public static record Redrive.Reserved(String body, Object handle, Map<String,String> headers) extends Record
A reserved DLQ message: its raw body, a transport-specific handle used to ack it, and any out-of-band transport headers (e.g. the replay-bypass marker; empty when none).
  • Constructor Details

    • Reserved

      public Reserved(String body, Object handle)
      A reserved message with no out-of-band headers.
    • Reserved

      public Reserved(String body, Object handle, Map<String,String> headers)
      Creates an instance of a Reserved record class.
      Parameters:
      body - the value for the body record component
      handle - the value for the handle record component
      headers - the value for the headers record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • body

      public String body()
      Returns the value of the body record component.
      Returns:
      the value of the body record component
    • handle

      public Object handle()
      Returns the value of the handle record component.
      Returns:
      the value of the handle record component
    • headers

      public Map<String,String> headers()
      Returns the value of the headers record component.
      Returns:
      the value of the headers record component