Record Class Redrive.Result

java.lang.Object
java.lang.Record
com.babelqueue.Redrive.Result
Enclosing class:
Redrive

public static record Redrive.Result(int redriven, int skipped, List<Redrive.Item> items) extends Record
  • Constructor Summary

    Constructors
    Constructor
    Description
    Result(int redriven, int skipped, List<Redrive.Item> items)
    Creates an instance of a Result record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    final boolean
    Indicates whether some other object is "equal to" this one.
    final int
    Returns a hash code value for this object.
    Returns the value of the items record component.
    int
    Returns the value of the redriven record component.
    int
    Returns the value of the skipped record component.
    final String
    Returns a string representation of this record class.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • Result

      public Result(int redriven, int skipped, List<Redrive.Item> items)
      Creates an instance of a Result record class.
      Parameters:
      redriven - the value for the redriven record component
      skipped - the value for the skipped record component
      items - the value for the items record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared with Objects::equals(Object,Object); primitive components are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • redriven

      public int redriven()
      Returns the value of the redriven record component.
      Returns:
      the value of the redriven record component
    • skipped

      public int skipped()
      Returns the value of the skipped record component.
      Returns:
      the value of the skipped record component
    • items

      public List<Redrive.Item> items()
      Returns the value of the items record component.
      Returns:
      the value of the items record component