Interface Replay.Effect

Enclosing class:
Replay
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface Replay.Effect
An action that may throw — the external side of a handler.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    run()