Uses of Interface
com.babelqueue.Replay.Effect
Packages that use Replay.Effect
-
Uses of Replay.Effect in com.babelqueue
Methods in com.babelqueue with parameters of type Replay.EffectModifier and TypeMethodDescriptionstatic voidReplay.bypassExternalEffects(Replay.Effect effect) Runseffectunless the current message is a replay, in which case it is skipped.static voidReplay.process(Map<String, String> headers, Replay.Effect body) Runsbodywith the replay flag derived from a reserved message's transport headers (the presence ofReplay.HEADER_REPLAY_BYPASS), restoring the prior flag afterwards.