Interface OutboxRelay.Sleeper

Enclosing class:
OutboxRelay
Functional Interface:
This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.

@FunctionalInterface public static interface OutboxRelay.Sleeper
Sleeps for a number of milliseconds between a failed publish and the next attempt.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    sleep(long millis)
    Sleep millis milliseconds (a no-op for millis <= 0).