Record Class OutboxRelayResult

java.lang.Object
java.lang.Record
com.babelqueue.outbox.OutboxRelayResult
Record Components:
published - rows the transport accepted and that were marked published
failed - rows whose publish threw; left pending for a later retry

public record OutboxRelayResult(int published, int failed) extends Record
Summary of an OutboxRelay run: how many pending rows were published and how many failed (and were left pending for a later retry). Returned by both OutboxRelay.flush() (one pass) and OutboxRelay.drain(int) (cumulative over all passes).
  • Constructor Summary

    Constructors
    Constructor
    Description
    OutboxRelayResult(int published, int failed)
    Creates an instance of a OutboxRelayResult record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    int
    Total rows the relay attempted (published + failed).
    final boolean
    Indicates whether some other object is "equal to" this one.
    int
    Returns the value of the failed record component.
    final int
    Returns a hash code value for this object.
    int
    Returns the value of the published record component.
    final String
    Returns a string representation of this record class.

    Methods inherited from class java.lang.Object

    clone, finalize, getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • OutboxRelayResult

      public OutboxRelayResult(int published, int failed)
      Creates an instance of a OutboxRelayResult record class.
      Parameters:
      published - the value for the published record component
      failed - the value for the failed record component
  • Method Details

    • attempted

      public int attempted()
      Total rows the relay attempted (published + failed).
    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with '=='.
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • published

      public int published()
      Returns the value of the published record component.
      Returns:
      the value of the published record component
    • failed

      public int failed()
      Returns the value of the failed record component.
      Returns:
      the value of the failed record component