Package com.babelqueue
Record Class Redrive.Item
java.lang.Object
java.lang.Record
com.babelqueue.Redrive.Item
- Enclosing class:
- Redrive
public static record Redrive.Item(String messageId, String traceId, String urn, String reason, String from, String to, boolean redriven, boolean bypassed)
extends Record
What happened to one message during a
Redrive.redrive(com.babelqueue.Redrive.Transport, java.lang.String, com.babelqueue.Redrive.Options) run.-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbooleanbypassed()Returns the value of thebypassedrecord component.final booleanIndicates whether some other object is "equal to" this one.from()Returns the value of thefromrecord component.final inthashCode()Returns a hash code value for this object.Returns the value of themessageIdrecord component.reason()Returns the value of thereasonrecord component.booleanredriven()Returns the value of theredrivenrecord component.to()Returns the value of thetorecord component.final StringtoString()Returns a string representation of this record class.traceId()Returns the value of thetraceIdrecord component.urn()Returns the value of theurnrecord component.
-
Constructor Details
-
Item
public Item(String messageId, String traceId, String urn, String reason, String from, String to, boolean redriven, boolean bypassed) Creates an instance of aItemrecord class.- Parameters:
messageId- the value for themessageIdrecord componenttraceId- the value for thetraceIdrecord componenturn- the value for theurnrecord componentreason- the value for thereasonrecord componentfrom- the value for thefromrecord componentto- the value for thetorecord componentredriven- the value for theredrivenrecord componentbypassed- the value for thebypassedrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. Reference components are compared withObjects::equals(Object,Object); primitive components are compared with '=='. -
messageId
Returns the value of themessageIdrecord component.- Returns:
- the value of the
messageIdrecord component
-
traceId
Returns the value of thetraceIdrecord component.- Returns:
- the value of the
traceIdrecord component
-
urn
Returns the value of theurnrecord component.- Returns:
- the value of the
urnrecord component
-
reason
Returns the value of thereasonrecord component.- Returns:
- the value of the
reasonrecord component
-
from
Returns the value of thefromrecord component.- Returns:
- the value of the
fromrecord component
-
to
Returns the value of thetorecord component.- Returns:
- the value of the
torecord component
-
redriven
public boolean redriven()Returns the value of theredrivenrecord component.- Returns:
- the value of the
redrivenrecord component
-
bypassed
public boolean bypassed()Returns the value of thebypassedrecord component.- Returns:
- the value of the
bypassedrecord component
-