Package com.babelqueue
Record Class Redrive.Reserved
java.lang.Object
java.lang.Record
com.babelqueue.Redrive.Reserved
- Enclosing class:
- Redrive
public static record Redrive.Reserved(String body, Object handle, Map<String,String> headers)
extends Record
A reserved DLQ message: its raw body, a transport-specific handle used to ack it, and any
out-of-band transport headers (e.g. the replay-bypass marker; empty when none).
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionbody()Returns the value of thebodyrecord component.final booleanIndicates whether some other object is "equal to" this one.handle()Returns the value of thehandlerecord component.final inthashCode()Returns a hash code value for this object.headers()Returns the value of theheadersrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
Reserved
A reserved message with no out-of-band headers. -
Reserved
Creates an instance of aReservedrecord class.- Parameters:
body- the value for thebodyrecord componenthandle- the value for thehandlerecord componentheaders- the value for theheadersrecord component
-
-
Method Details
-
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
body
Returns the value of thebodyrecord component.- Returns:
- the value of the
bodyrecord component
-
handle
Returns the value of thehandlerecord component.- Returns:
- the value of the
handlerecord component
-
headers
Returns the value of theheadersrecord component.- Returns:
- the value of the
headersrecord component
-