Package com.babelqueue.outbox
Interface OutboxRelay.Sleeper
- Enclosing class:
- OutboxRelay
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
Sleeps for a number of milliseconds between a failed publish and the next attempt.
-
Method Summary
Modifier and TypeMethodDescriptionvoidsleep(long millis) Sleepmillismilliseconds (a no-op formillis <= 0).
-
Method Details
-
sleep
Sleepmillismilliseconds (a no-op formillis <= 0).- Throws:
InterruptedException
-