Package com.babelqueue.outbox
Record Class OutboxRelayResult
java.lang.Object
java.lang.Record
com.babelqueue.outbox.OutboxRelayResult
- Record Components:
published- rows the transport accepted and that were marked publishedfailed- rows whose publish threw; left pending for a later retry
Summary of an
OutboxRelay run: how many pending rows were published and how many failed
(and were left pending for a later retry). Returned by both OutboxRelay.flush() (one pass)
and OutboxRelay.drain(int) (cumulative over all passes).-
Constructor Summary
ConstructorsConstructorDescriptionOutboxRelayResult(int published, int failed) Creates an instance of aOutboxRelayResultrecord class. -
Method Summary
Modifier and TypeMethodDescriptionintTotal rows the relay attempted (published + failed).final booleanIndicates whether some other object is "equal to" this one.intfailed()Returns the value of thefailedrecord component.final inthashCode()Returns a hash code value for this object.intReturns the value of thepublishedrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
Method Details
-
attempted
public int attempted()Total rows the relay attempted (published + failed). -
toString
Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components. -
hashCode
public final int hashCode()Returns a hash code value for this object. The value is derived from the hash code of each of the record components. -
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with '=='. -
published
public int published()Returns the value of thepublishedrecord component.- Returns:
- the value of the
publishedrecord component
-
failed
public int failed()Returns the value of thefailedrecord component.- Returns:
- the value of the
failedrecord component
-